@@ -10,13 +10,16 @@
 #'
 rhoMax1dep <- function(p){
   m <- length(p)
+  if(m==1){
+    return(1)
+  }else{
   rholimit <- rep(1,m-1)
 
   rholimit[1] <- sqrt(p[2]*(1-p[1])/p[1]/(1-p[2]))
   for (i in 2:(m-1)){
     rholimit[i] <- rhoMaxMdep1(p[i-1],p[i],p[i+1])
   }
-  return( rholimit )
+  return( rholimit )}
 }
 
 #sqrt(p[i]*(1-p[i+1])/p[i+1]/(1-p[i]))
